@@ -63,7 +63,7 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
 
     metadata = metadata_module.PrimitiveMetadata({
         'id': '69845479-0b61-3578-b382-972cd0e61d69',
-        'version': '2.0.9',
+        'version': '2.0.10',
         'name': 'IPCMB feature selector',
         'keywords': 'rpi primitives',
         'source': {
@@ -97,15 +97,15 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
         self.training_outputs = None
         self.fitted = False
 
-    def set_training_data(self, inputs: Inputs, outputs: Outputs) -> None:
+    def set_training_data(self, *, inputs: Inputs, outputs: Outputs) -> None:
         self.training_inputs = inputs
         self.training_outputs = outputs
         self.fitted = False
 
 
-    def fit(self) -> None:
+    def fit(self, *, timeout: float = None, iterations: int = None) -> None:
         if self.fitted:
-            return True
+            return CallResult(None)
 
         if self.training_inputs.any() == None or self.training_outputs.any() == None:
             raise ValueError('Missing training data, or missing values exist.')
@@ -123,7 +123,7 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
         return CallResult(None)
 
 
-    def produce(self, inputs: Inputs) -> Outputs:  # inputs: m x n numpy array
+    def produce(self, *, inputs: Inputs, timeout: float = None, iterations: int = None) -> Outputs:  # inputs: m x n numpy array
         if self.fitted:
             return CallResult(inputs[:, self.index])
         else:
@@ -134,7 +134,7 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
         pass
 
 
-    def set_params(self):
+    def set_params(self) -> None:
         pass
 
 
